pub struct ReturnItem {
    pub seller_return_item_id: String,
    pub seller_fulfillment_order_item_id: String,
    pub amazon_shipment_id: String,
    pub seller_return_reason_code: String,
    pub return_comment: Option<String>,
    pub amazon_return_reason_code: Option<String>,
    pub status: FulfillmentReturnItemStatus,
    pub status_changed_date: String,
    pub return_authorization_id: Option<String>,
    pub return_received_condition: Option<ReturnItemDisposition>,
    pub fulfillment_center_id: Option<String>,
}
ReturnItem : An item that Amazon accepted for return.

Fields

seller_return_item_id: String

An identifier assigned by the seller to the return item.

seller_fulfillment_order_item_id: String

The identifier assigned to the item by the seller when the fulfillment order was created.

amazon_shipment_id: String

The identifier for the shipment that is associated with the return item.

seller_return_reason_code: String

The return reason code assigned to the return item by the seller.

return_comment: Option<String>

An optional comment about the return item.

amazon_return_reason_code: Option<String>

The return reason code that the Amazon fulfillment center assigned to the return item.

status: FulfillmentReturnItemStatusstatus_changed_date: Stringreturn_authorization_id: Option<String>

Identifies the return authorization used to return this item. See ReturnAuthorization.

return_received_condition: Option<ReturnItemDisposition>fulfillment_center_id: Option<String>

The identifier for the Amazon fulfillment center that processed the return item.

Implementations

An item that Amazon accepted for return.