pub struct ReturnItem {
pub seller_return_item_id: String,
pub seller_fulfillment_order_item_id: String,
pub amazon_shipment_id: String,
pub seller_return_reason_code: String,
pub return_comment: Option<String>,
pub amazon_return_reason_code: Option<String>,
pub status: FulfillmentReturnItemStatus,
pub status_changed_date: String,
pub return_authorization_id: Option<String>,
pub return_received_condition: Option<ReturnItemDisposition>,
pub fulfillment_center_id: Option<String>,
}Expand description
ReturnItem : An item that Amazon accepted for return.
Fields
seller_return_item_id: StringAn identifier assigned by the seller to the return item.
seller_fulfillment_order_item_id: StringThe identifier assigned to the item by the seller when the fulfillment order was created.
amazon_shipment_id: StringThe identifier for the shipment that is associated with the return item.
seller_return_reason_code: StringThe return reason code assigned to the return item by the seller.
return_comment: Option<String>An optional comment about the return item.
amazon_return_reason_code: Option<String>The return reason code that the Amazon fulfillment center assigned to the return item.
status: FulfillmentReturnItemStatusstatus_changed_date: StringIdentifies the return authorization used to return this item. See ReturnAuthorization.
return_received_condition: Option<ReturnItemDisposition>fulfillment_center_id: Option<String>The identifier for the Amazon fulfillment center that processed the return item.
Implementations
sourceimpl ReturnItem
impl ReturnItem
sourcepub fn new(
seller_return_item_id: String,
seller_fulfillment_order_item_id: String,
amazon_shipment_id: String,
seller_return_reason_code: String,
status: FulfillmentReturnItemStatus,
status_changed_date: String
) -> ReturnItem
pub fn new(
seller_return_item_id: String,
seller_fulfillment_order_item_id: String,
amazon_shipment_id: String,
seller_return_reason_code: String,
status: FulfillmentReturnItemStatus,
status_changed_date: String
) -> ReturnItem
An item that Amazon accepted for return.